import { select,
        json,
        tree,
       	hierarchy,
        linkHorizontal,
        event,
        zoom
       } from 'd3';

const svg = select('svg');
const width = document.body.clientWidth;
const height = document.body.clientHeight;

const margin = { top: 0, right:30, bottom: 0, left:70 };
const innerWidth = width - margin.left - margin.right;
const innerHeight = height - margin.top - margin.bottom;

const treeLayout = tree().size([innerHeight, innerWidth]);

const zoomG = svg
		.attr('width', width)
    .attr('height', height)
	

const g = zoomG.append('g')
		.attr('transform', `translate(${margin.left}, ${margin.top})`);

svg.call(zoom().on('zoom', () => {
	zoomG.attr('transform', event.transform)
}));

json('data.json')
	.then( data => {
	const root = hierarchy(data);
  const links = treeLayout(root).links();
  const linkPathGenerator = linkHorizontal()
  	.x(d => d.y)
  	.y(d => d.x);
  
  g.selectAll('path').data(links)
  	.enter().append('path')
  		.attr('d', linkPathGenerator)
  
//   const node = g.append('g')
//   	.selectAll('g').data(root.descendants())
  
  const node = g.append('g')
    .selectAll('g')
    .data(root.descendants())
    .join('g')
  		.attr('transform', d => `translate(${d.y},${d.x})`);
  
  node.append('text')
    .attr('x', d => d.children ? 6 : 6)
  	.attr('dy', '0.32em')
  	.attr('text-anchor', d => d.children ? 'middle' : 'start')
  	.attr('font-size', d => 3.1 - d.depth + 'em')
    .text(d => d.data.data.id);
  
  node.append('circle')
    .attr('fill', d => d.children ? '#555' : '#999')
    .attr('r', d => 4 - d.depth);
})